#
# spec file for package gum
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global _lto_cflags %nil
Name:           gum
Version:        0.13.0
Release:        2.1
Summary:        Tool for glamorous shell scripts
License:        MIT
URL:            https://github.com/charmbracelet/gum
Source0:        https://github.com/charmbracelet/gum/archive/refs/tags/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
Source1:        vendor.tar.zst
BuildRequires:  zstd
BuildRequires:  golang(API)

%description
Gum leverages the power of Bubbles and Lip Gloss in your scripts and aliases.

%package bash-completion
Summary:        Bash Completion for %{name}
Group:          System/Shells
Supplements:    (%{name} and bash-completion)
Requires:       bash-completion
BuildArch:      noarch

%description bash-completion
Bash command-line completion support for %{name}.

%package fish-completion
Summary:        Fish Completion for %{name}
Group:          System/Shells
Supplements:    (%{name} and fish)
Requires:       fish
BuildArch:      noarch

%description fish-completion
Fish command-line completion support for %{name}.

%package zsh-completion
Summary:        Zsh Completion for %{name}
Group:          System/Shells
Supplements:    (%{name} and zsh)
Requires:       zsh
BuildArch:      noarch

%description zsh-completion
Zsh command-line completion support for %{name}.

%prep
%setup -qa1

%build
%ifarch ppc64
BUILDMOD=""
%else
BUILDMOD="-buildmode=pie"
%endif
export CGO_CFLAGS="%{optflags}"
export CGO_CXXFLAGS="%{optflags}"
export CGO_CPPFLAGS="%{optflags}"
go build -v -x -mod=vendor $BUILDMOD -a -ldflags "-s -X main.Version=%{version}"

%install
install -Dm755 %{name} %{buildroot}%{_bindir}/%{name}

# Completions
for sh in bash zsh fish; do
  ./%{name} completion $sh > %{name}.${sh}
done
install -Dm644 %{name}.bash %{buildroot}%{_datadir}/bash-completion/completions/%{name}
install -Dm644 %{name}.zsh %{buildroot}%{_datadir}/zsh/site-functions/_%{name}
install -Dm644 %{name}.fish %{buildroot}%{_datadir}/fish/vendor_completions.d/%{name}.fish

%files
%{_bindir}/%{name}
%license LICENSE
%doc README.md

%files bash-completion
%{_datadir}/bash-completion/*

%files fish-completion
%dir %{_datadir}/fish
%{_datadir}/fish/*

%files zsh-completion
%dir %{_datadir}/zsh
%{_datadir}/zsh/*

%changelog
* Wed Feb 14 2024 Joshua Smith <jsmithfpv@gmail.com>
- Enabled completions for bash, zsh and fish.
* Tue Jan 16 2024 Joshua Smith <jsmithfpv@gmail.com>
- Update to 0.13.0:
  New:
  * Add --select-if-one flag to gum choose and gum filter
  * Added brand new log command. Gum log logs messages to the
    terminal at different levels and styling
  * Pager search functionality
  * Strip ANSI for gum filter and gum choose when output is not
    a TTY
  * Non-positive widths will cause gum write will use the entire
    terminal width
  * GUM_FORMAT_THEME / GUM_FORMAT_LANGUAGE environment variables
  * --no-sort flag for gum filter
  * Customizable cursor modes and line text
  * Add --timeout flag to all subcommands
  * Truecolor support added to gum style
  * Context headers for gum choose and gum filter
  * Keep order of selected items in gum choose with --ordered
  * Pass programming language for gum format
  * Customize format theme, including using glamour json theme
    files
  * gum choose now supports tab and ctrl+j/k keybindings
  * add --file and --directory flags to select each in gum file
  * gum pager --soft-wrap option added
  * gum style pass input to style over stdin
  * ability to add --header values
  Fixes:
  * showoutput flag displays in realtime
  * Pretty Table Print improved
  * Avoid reading from stdin if --value is being used
  * Made filter work with losts as choose
  * Respect file path argument in filepicker
  * --all option defaults to false
  * exit with status 130 if escape key pressed on gum write
  * symlink directory follows link in gum file
  * allow exact match in gum filter
* Fri Feb 17 2023 Soc Virnyl Estela <socvirnyl.estela@gmail.com>
- Initial spec for gum 0.8.0
